
<!---
FrozenIsBool True
-->

##Example

Here we watch a MakerClass that sets its WatchBeforeMakeWithMaker and WatchAfterMakeWithMaker when the make method is called.
Also we can already set reactive method when these properties change.